==> open-cluster-management-policy-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorsplacementrule/apps/v1/PlacementDecisionFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PlacementDecisionFluent<A extends PlacementDecisionFluent<A>> extends BaseFluent<A>{
  public PlacementDecisionFluent() {
  }
  
  public PlacementDecisionFluent(PlacementDecision instance) {
    this.copyInstance(instance);
  }
  private String clusterName;
  private String clusterNamespace;
  
  protected void copyInstance(PlacementDecision instance) {
    instance = (instance != null ? instance : new PlacementDecision());
  
    if (instance != null) {
        this.withClusterName(instance.getClusterName());
        this.withClusterNamespace(instance.getClusterNamespace());
        this.withClusterName(instance.getClusterName());
        this.withClusterNamespace(instance.getClusterNamespace());
      }
  }
  
  public String getClusterName() {
    return this.clusterName;
  }
  
  public A withClusterName(String clusterName) {
    this.clusterName=clusterName; return (A) this;
  }
  
  public boolean hasClusterName() {
    return this.clusterName != null;
  }
  
  public String getClusterNamespace() {
    return this.clusterNamespace;
  }
  
  public A withClusterNamespace(String clusterNamespace) {
    this.clusterNamespace=clusterNamespace; return (A) this;
  }
  
  public boolean hasClusterNamespace() {
    return this.clusterNamespace != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementDecisionFluent that = (PlacementDecisionFluent) o;
    if (!java.util.Objects.equals(clusterName, that.clusterName)) return false;
  
    if (!java.util.Objects.equals(clusterNamespace, that.clusterNamespace)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(clusterName,  clusterNamespace,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterName != null) { sb.append("clusterName:"); sb.append(clusterName + ","); }
    if (clusterNamespace != null) { sb.append("clusterNamespace:"); sb.append(clusterNamespace); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> open-cluster-management-policy-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorsplacementrule/apps/v1/PlacementDecisionFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PlacementDecisionFluent<A extends PlacementDecisionFluent<A>> extends BaseFluent<A>{
  public PlacementDecisionFluent() {
  }
  
  public PlacementDecisionFluent(PlacementDecision instance) {
    this.copyInstance(instance);
  }
  private String clusterName;
  private String clusterNamespace;
  
  protected void copyInstance(PlacementDecision instance) {
    instance = (instance != null ? instance : new PlacementDecision());
    if (instance != null) {
          this.withClusterName(instance.getClusterName());
          this.withClusterNamespace(instance.getClusterNamespace());
          this.withClusterName(instance.getClusterName());
          this.withClusterNamespace(instance.getClusterNamespace());
        }
  }
  
  public String getClusterName() {
    return this.clusterName;
  }
  
  public A withClusterName(String clusterName) {
    this.clusterName = clusterName;
    return (A) this;
  }
  
  public boolean hasClusterName() {
    return this.clusterName != null;
  }
  
  public String getClusterNamespace() {
    return this.clusterNamespace;
  }
  
  public A withClusterNamespace(String clusterNamespace) {
    this.clusterNamespace = clusterNamespace;
    return (A) this;
  }
  
  public boolean hasClusterNamespace() {
    return this.clusterNamespace != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementDecisionFluent that = (PlacementDecisionFluent) o;
    if (!java.util.Objects.equals(clusterName, that.clusterName)) return false;
    if (!java.util.Objects.equals(clusterNamespace, that.clusterNamespace)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(clusterName,  clusterNamespace,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterName != null) { sb.append("clusterName:"); sb.append(clusterName + ","); }
    if (clusterNamespace != null) { sb.append("clusterNamespace:"); sb.append(clusterNamespace); }
    sb.append("}");
    return sb.toString();
  }
  

}
